# Toby Doom Launcher

The Toby Doom Launcher is a game launcher designed to help players easily configure and start various Doom-based games using the Toby Doom Accessibility Mod.

## Quick Start

1. Download the [Windows package](https://stormux.org/downloads/toby_doom_launcher.zip) or install dependencies for running from source
2. Place the launcher in your Toby Doom Accessibility Mod directory
3. Select your IWAD and game variant
4. Choose your narration style and start playing!

## Features

- Support for multiple game variants including Classic Doom, Toby Doom, Heretic, and Hexen
- Single-player, deathmatch, and co-op gameplay modes
- Custom game configuration support
- Built-in audio manual player
- Text-to-speech integration for game feedback

## System Requirements

When running from source:
- GZDoom 4.9 or higher
- Python 3.9 or higher
- PySide6 6.0 or higher
- VLC media player (for audio manual)
- Required speech providers:
  - Windows: Accessible Output 2
  - Linux: Speech Dispatcher or Cthulhu
  - Mac: Support planned for future release

The Windows package includes all required dependencies except GZDoom and VLC.

## Installation - Linux

1. Install required dependencies from your distribution's package manager
2. Extract Toby Doom to ~/.local/games/doom
3. The launcher itself can run from anywhere on the system
4. The TobyCustom directory can be placed in any of these locations:
   - Same directory as the launcher
   - ~/.local/games/doom/TobyCustom
   - ~/.local/share/doom/TobyCustom
5. Additional IWADs can be placed in ~/.local/share/doom

## Installation - Mac

Mac support is planned for a future release. Currently, the launcher has not been tested on macOS.

## Installation - Windows

Using the pre-packaged version:
1. Download the [launcher package](https://stormux.org/downloads/toby_doom_launcher.zip)
2. Extract it to the top level of your Toby Accessibility Mod directory
3. Install VLC media player if you want to use the audio manual
4. For multiplayer, download [freedm](https://github.com/freedoom/freedoom/releases/download/v0.13.0/freedm-0.13.0.zip) and place freedm.wad in the Toby Doom Accessibility Mod directory

Running from source:
1. Install Python 3.9 or higher
2. Install PySide6 (`pip install PySide6`)
3. Install other required Python packages
4. Place the launcher in the top level of the Toby Accessibility Mod directory

## Usage

### Basic Navigation

- Use Tab and Shift+Tab to move between controls
- Use arrow keys to navigate combo boxes
- Press Enter to activate buttons
- Press Escape to close dialogs or exit the launcher

### Important Note for NVDA Users on Windows

When using NVDA, you may need to press Alt+DownArrow to expand combo boxes if they don't respond to the normal arrow keys.

### Game Selection

1. Choose your IWAD from the dropdown menu
2. Select your desired game variant
3. Choose your preferred narration style (Self-voiced or Text to Speech)
4. Select your gameplay mode:
   - Single Player: Start a solo game
   - Deathmatch: Configure and start a multiplayer deathmatch
   - Custom Deathmatch: Play deathmatch with custom modifications
   - Co-op: Set up or join a cooperative multiplayer game

### Multiplayer Setup

#### Deathmatch
- Select arena map
- Configure options like frag limit, player count, and skill level
- Choose between hosting, joining, or playing with bots
- When playing with bots, use the console (`) to add bots with the "addbot" command

#### Co-op
- Host or join a cooperative game
- Set player count and skill level
- Uses universal keyshare for better cooperative gameplay

### Audio Manual

The launcher includes an accessible audio manual player with these features:
- Browse and select manual sections
- Full keyboard control for playback
- Play individual tracks or entire manual
- Previous/Next track navigation
- Requires VLC media player for audio playback

## File Organization

The launcher expects the following directory structure:

```
/
â TobyAccMod_V[version].pk3
â Addons/
â â MAPS/
â â MENU/
â â [Game-specific folders]/
â Manual/
â TobyCustom/
```

## Customization

Custom games can be configured using JSON files in the TobyCustom directory. This allows for:
- Custom game configurations
- Additional WAD and PK3 file loading
- Special launch parameters
- Dependency management

## Troubleshooting

- If GZDoom fails to launch, verify the executable is in your PATH or game directory
- For multiplayer, ensure freedm.wad is available in your game directory
- Check file permissions if unable to save narration settings
- Verify VLC is installed if audio manual playback fails
- Ensure speech providers are properly configured for your platform

## Additional Resources

- [MrAlanD1's Youtube Channel](https://www.youtube.com/@MrAlanD1)
- [Toby Doom topic on the zdoom forum](https://forum.zdoom.org/viewtopic.php?t=71349&hilit=toby+accessibility&sid=f874cf335c6bbb63ef4408610ae9fe5b)
- The Stormux email list, join at <https://stormux.org>

## License

This software is distributed under the GNU Lesser General Public License v3.0 (LGPL-3.0).
